@@ -44,7 +44,6 @@ pub enum ApplicationEvent {
     },
     ProcessExit {
         tag: ProcessTag,
-        success: bool,
     },
 }
 
@@ -102,8 +101,8 @@ impl ServerApplication {
         let mut client_event_receiver = ClientEventReceiver::default();
 
         if source_default_config {
-            let source = include_str!("default_config.pp");
-            match CommandManager::eval_commands_then_output(
+            let source = include_str!("../rc/default_config.pp");
+            match CommandManager::eval_and_then_output(
                 &mut editor,
                 platform,
                 &mut clients,
@@ -161,8 +160,8 @@ impl ServerApplication {
                     ApplicationEvent::ProcessOutput { tag, buf } => {
                         editor.on_process_output(platform, &mut clients, tag, buf.as_bytes())
                     }
-                    ApplicationEvent::ProcessExit { tag, success } => {
-                        editor.on_process_exit(platform, &mut clients, tag, success)
+                    ApplicationEvent::ProcessExit { tag } => {
+                        editor.on_process_exit(platform, &mut clients, tag)
                     }
                 }
 
@@ -228,11 +227,7 @@ impl<'stdout> ClientApplication<'stdout> {
         2 * 1024
     }
 
-    pub fn new(
-        handle: ClientHandle,
-        stdout: io::StdoutLock<'stdout>,
-        is_pipped: bool,
-    ) -> Self {
+    pub fn new(handle: ClientHandle, stdout: io::StdoutLock<'stdout>, is_pipped: bool) -> Self {
         Self {
             handle,
             is_pipped,
@@ -268,9 +263,10 @@ impl<'stdout> ClientApplication<'stdout> {
                 Some(position) => {
                     writeln!(
                         commands,
-                        "open '{}' -line={}",
+                        "open '{}' -line={} -column={}",
                         path,
-                        position.line_index + 1
+                        position.line_index + 1,
+                        position.column_byte_index + 1,
                     )
                     .unwrap();
                 }
