@@ -31,7 +31,7 @@ impl State {
             return self.lsp_client_handle;
         }
 
-        let buffer_path = buffer_path.to_str()?.as_bytes();
+        let buffer_path = buffer_path.to_str()?;
         let handle = lsp_clients
             .clients()
             .find(|c| c.handles_path(buffer_path))
@@ -152,9 +152,10 @@ impl ModeState for State {
                         .content()
                         .word_at(BufferPosition::line_col(position.line_index, 0));
                     if indentation_word.kind == WordKind::Whitespace {
-                        let indentation_len =
-                            position.column_byte_index.min(indentation_word.text.len());
-                        buf.push_str(&indentation_word.text[..indentation_len]);
+                        let indentation_len = position
+                            .column_byte_index
+                            .min(indentation_word.text.len() as _);
+                        buf.push_str(&indentation_word.text[..indentation_len as usize]);
                     }
 
                     buffer.insert_text(
@@ -257,7 +258,7 @@ fn update_completions(ctx: &mut ModeContext, buffer_view_handle: BufferViewHandl
     let main_cursor_position = buffer_view.cursors.main_cursor().position;
     let word = content.word_at(content.position_before(main_cursor_position));
 
-    let lsp_client_handle = state.get_lsp_client_handle(&ctx.editor.lsp, buffer.path());
+    let lsp_client_handle = state.get_lsp_client_handle(&ctx.editor.lsp, &buffer.path);
 
     let mut force_trigger_completion = false;
     if let Some(last_char) = word.text.chars().next_back() {
@@ -372,11 +373,11 @@ fn apply_completion(
                 None => return,
             };
             let state = &mut ctx.editor.mode.insert_state;
-            let lsp_client_handle =
-                match state.get_lsp_client_handle(&ctx.editor.lsp, buffer.path()) {
-                    Some(handle) => handle,
-                    None => return,
-                };
+            let lsp_client_handle = match state.get_lsp_client_handle(&ctx.editor.lsp, &buffer.path)
+            {
+                Some(handle) => handle,
+                None => return,
+            };
 
             let content = buffer.content();
             state.completion_positions.clear();
